##
## CEM on Lalonde data example
## from Pashley & Miratrix
## Insights on Variance Estimation for Blocked and Matched Pairs Designs
##
## Using GitHub blkvar package
## https://github.com/lmiratrix/blkvar/releases/tag/insights
##
## (C) 2020 N. Pashley & L. Miratrix
##

library(cem)
library(blkvar)

# We will follow vignette:
# https://cran.r-project.org/web/packages/cem/vignettes/cem.pdf
# Lalonde data (we use original rather than modified "LeLonde")
data(LL, package="cem")

#Remove missing data
Le <- data.frame(na.omit(LL))
tr <- which(Le$treated==1)
ct <- which(Le$treated==0)
ntr <- length(tr)
nct <- length(ct)

#Variables we would like to match on (we don't use fictitious "q1")
vars <- c("age", "education", "black", "married", "nodegree", "re74",
          "re75", "hispanic", "u74", "u75")

# Baseline imbalance
cem::imbalance(group=Le$treated, data=Le[vars])

#Match
mat <- cem(treatment = "treated", data = Le, drop = "re78", keep.all=TRUE)
mat
mat$strata
mat$n.strata
length( mat$strata )

Le$Blk_ID = as.factor( mat$strata )

# Look at how we have tx and co in different blocks
table( Le$treated, Le$Blk_ID )

# Look at homogenous blocks (two picked mostly at random)
filter( Le, Blk_ID == "145" )
filter( Le, Blk_ID == "84" )


#Note that some units were not matched to another unit
#Reduce data to just those who were matched
Le = Le %>% group_by( Blk_ID ) %>%
    mutate( ptx = mean( treated ) ) %>%
    ungroup()
LeSub = filter( Le, ptx > 0, ptx < 1 )

# Number blocks left
length( unique( LeSub$Blk_ID ) )

# For interest: We can calculate block level statistics
blocks_sum<-calc_summary_stats( re78, treated, Blk_ID, data=LeSub, add.neyman = TRUE )
head( blocks_sum )

#Get variance estimates
result = block_estimator_tabulated( blocks_sum, method = "hybrid_p" )

result



compare_methods( re78, treated, Blk_ID, data=LeSub,
                include_MLM = FALSE,
                include_DB = FALSE,
                weight_LM_method = c("precision"))
