##
## "Fish" data example
## from Pashley & Miratrix
## Insights on Variance Estimation for Blocked and Matched Pairs Designs
##
## Using GitHub blkvar package
## https://github.com/lmiratrix/blkvar/releases/tag/insights
##
## (C) 2020 N. Pashley & L. Miratrix
##

library(CrossScreening)
library(sandwich)
library(blkvar)
library(brglm)
library(optmatch)
library( ggplot2 )

##Get fish data
data(nhanes.fish)
head(nhanes.fish)


## Match our data
fish.dat<-nhanes.fish
fish.dat$outcome<-log(fish.dat$o.LBXBGM,2)

#Form treatment indicator
fish.dat$trt<-ifelse( fish.dat$fish.level=="low", 0, 1 )

#Buid propensity scores
#Match on same things as mentioned in Zhao, Small, & Rosenbaum (2018)
var_match<-c("gender", "age", "income", "income.missing", "race", "education",
             "smoking.ever", "smoking.now")
form1<-reformulate(var_match, response="trt")
model1<-brglm(form1, family="binomial", data=fish.dat)
fish.dat$propscore<-predict(model1)

# Distriution of p-scores: decent overlap
ggplot( fish.dat, aes( propscore, col=as.factor(trt), group=trt ) ) +
    geom_density() +
    labs( color="Tx Group", x="logit( pscore )")

#Get propensity score distances
propsdist<-match_on(trt~propscore, data=fish.dat)

#Get matching
match1<-fullmatch(propsdist, tol = 1e-05, data=fish.dat)
summary(match1)

# Stash block IDs from matching
fish.dat$match1<-match1

#Get variance estimates
result = block_estimator( outcome, trt, match1, data=fish.dat,
         method = "hybrid_p" )

class( result )
result

# Size of each block
head( result$block_sizes )


# Compare the different estimation methods
cp <- compare_methods( outcome, trt, match1, data=fish.dat,
                 include_MLM = FALSE, include_DB = FALSE,
                 weight_LM_method = c("precision"))
knitr::kable( cp, digits= 2 )


